from setuptools import setup

setup(
    name="chain-helloworld-library",
    version='1.0',
    package_dir={'' : 'src'},
    packages=['HelloWorld'],
    url='https://github.com/kachain2019/demo-helloworld-library',
    author='kachain',
    author_email='kachain2019.a@gmail.com',
)
