from HelloWorldKeywords import HelloWorldKeywords

class HelloWorld(HelloWorldKeywords):

    """ A keyword library for Robot Framework. It provides keywords for
        learning how to create a new library. For more information
        on underlying methods and documentation, see:
            http://eclipse.org/paho/clients/python/docs/
    """

    ROBOT_LIBRARY_SCOPE = 'TEST_CASE'
